about summary refs log tree commit diff
path: root/src/test
diff options
context:
space:
mode:
authorVadim Petrochenkov <vadim.petrochenkov@gmail.com>2019-01-26 00:36:50 +0300
committerVadim Petrochenkov <vadim.petrochenkov@gmail.com>2019-01-26 01:49:55 +0300
commit1b659d69bc0ba7fe534cc26bda8544a558a7d2b2 (patch)
treec702f5a45edc951a503130163b89f4f1f1fcb0ad /src/test
parentac4b685650d1ba0a38806ce8f7cbf12e7a00f573 (diff)
downloadrust-1b659d69bc0ba7fe534cc26bda8544a558a7d2b2.tar.gz
rust-1b659d69bc0ba7fe534cc26bda8544a558a7d2b2.zip
Address review comments and cleanup code
Diffstat (limited to 'src/test')
-rw-r--r--src/test/ui/issues/issue-56411.rs6
-rw-r--r--src/test/ui/issues/issue-56411.stderr22
-rw-r--r--src/test/ui/issues/issue_56411_aux.rs (renamed from src/test/ui/issues/issue_56411.rs)0
3 files changed, 14 insertions, 14 deletions
diff --git a/src/test/ui/issues/issue-56411.stderr b/src/test/ui/issues/issue-56411.stderr
index 842d86f4a3a..dd05852c091 100644
--- a/src/test/ui/issues/issue-56411.stderr
+++ b/src/test/ui/issues/issue-56411.stderr
@@ -1,29 +1,29 @@
-error[E0255]: the name `issue_56411` is defined multiple times
+error[E0255]: the name `issue_56411_aux` is defined multiple times
   --> $DIR/issue-56411.rs:5:21
    |
 LL |             mod $name;
-   |             ---------- previous definition of the module `issue_56411` here
+   |             ---------- previous definition of the module `issue_56411_aux` here
 LL |             pub use self::$name;
    |                     ^^^^^^^^^^^
    |                     |
-   |                     `issue_56411` reimported here
+   |                     `issue_56411_aux` reimported here
    |                     you can use `as` to change the binding name of the import
 ...
-LL | import!(issue_56411);
-   | --------------------- in this macro invocation
+LL | import!(issue_56411_aux);
+   | ------------------------- in this macro invocation
    |
-   = note: `issue_56411` must be defined only once in the type namespace of this module
+   = note: `issue_56411_aux` must be defined only once in the type namespace of this module
 
-error[E0365]: `issue_56411` is private, and cannot be re-exported
+error[E0365]: `issue_56411_aux` is private, and cannot be re-exported
   --> $DIR/issue-56411.rs:5:21
    |
 LL |             pub use self::$name;
-   |                     ^^^^^^^^^^^ re-export of private `issue_56411`
+   |                     ^^^^^^^^^^^ re-export of private `issue_56411_aux`
 ...
-LL | import!(issue_56411);
-   | --------------------- in this macro invocation
+LL | import!(issue_56411_aux);
+   | ------------------------- in this macro invocation
    |
-   = note: consider declaring type or module `issue_56411` with `pub`
+   = note: consider declaring type or module `issue_56411_aux` with `pub`
 
 error: aborting due to 2 previous errors
 
diff --git a/src/test/ui/issues/issue_56411.rs b/src/test/ui/issues/issue_56411_aux.rs
index bd689e913ab..bd689e913ab 100644
--- a/src/test/ui/issues/issue_56411.rs
+++ b/src/test/ui/issues/issue_56411_aux.rs
diff --git a/src/test/ui/issues/issue-56411.rs b/src/test/ui/issues/issue-56411.rs
index 599f277123c..3561c21cc7e 100644
--- a/src/test/ui/issues/issue-56411.rs
+++ b/src/test/ui/issues/issue-56411.rs
@@ -3,14 +3,14 @@ macro_rules! import {
         $(
             mod $name;
             pub use self::$name;
             //~^ ERROR the name `issue_56411` is defined multiple times
             //~| ERROR `issue_56411` is private, and cannot be re-exported
 
         )*
     }
 }
 
-import!(issue_56411);
+import!(issue_56411_aux);
 
 fn main() {
     println!("Hello, world!");
@@ -3,14 +3,14 @@ macro_rules! import {
             mod $name;
             pub use self::$name;
-            //~^ ERROR the name `issue_56411` is defined multiple times
-            //~| ERROR `issue_56411` is private, and cannot be re-exported
+            //~^ ERROR the name `issue_56411_aux` is defined multiple times
+            //~| ERROR `issue_56411_aux` is private, and cannot be re-exported
 
         )*